Package: antiProfiles
Maintainer: Hector Corrada Bravo <hcorrada@gmail.com>
Author: Hector Corrada Bravo, Rafael A. Irizarry and Jeffrey T. Leek
Version: 1.50.0
License: Artistic-2.0
Title: Implementation of gene expression anti-profiles
Description: Implements gene expression anti-profiles as described in Corrada
    Bravo et al., BMC Bioinformatics 2012, 13:272 doi:10.1186/1471-2105-13-272.
Depends: R (>= 3.0), matrixStats (>= 0.50.0), methods (>= 2.14), locfit
        (>= 1.5)
URL: https://github.com/HCBravoLab/antiProfiles
biocViews: GeneExpression,Classification
Suggests: antiProfilesData, RColorBrewer
Collate: 'AllClasses.r' 'AllGenerics.r' 'show-methods.r'
        'antiProfiles-package.r' 'ap-methods.r' 'apCounts-methods.r'
        'apReorder-methods.r' 'apStats.r' 'accessors.r' 'ev.R'
RoxygenNote: 5.0.1
git_url: https://git.bioconductor.org/packages/antiProfiles
git_branch: RELEASE_3_22
git_last_commit: bac01fd
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: no
Packaged: 2025-10-30 02:30:44 UTC; biocbuild
