#' Gene Expression Anti-profiles
#' 
#' This package implements the anti-profile method of Corrada Bravo et al., BMC Bioinformatics 2012, 13:272 doi:10.1186/1471-2105-13-272.
#' 
#' @author Hector Corrada Bravo \email{hcorrada@@gmail.com}
#'   
#' @name antiProfiles-package
#' @rdname antiProfiles-package
#' @docType package
NULL
